asr.test.fixtures
=================

.. automodule:: asr.test.fixtures

   
   
   .. rubric:: Functions

   
   .. autofunction:: asr_tmpdir
   .. autofunction:: asr_tmpdir_w_params
   .. autofunction:: duplicates_test_db
   .. autofunction:: get_webcontent
   .. autofunction:: mockgpaw
   .. autofunction:: set_asr_test_environ_variable
   .. autofunction:: test_material
   
   

   
   
   

   
   
   